==> aliyun-gateway-pop-0.1.13-beta-sources.jar: com/aliyun/sdk/gateway/pop/interceptor/request/V3ReqInterceptor.java <==
package com.aliyun.sdk.gateway.pop.interceptor.request;

import com.aliyun.sdk.gateway.pop.auth.SignatureVersion;
import com.aliyun.sdk.gateway.pop.auth.signer.PopSigner;
import com.aliyun.core.http.FormatType;
import com.aliyun.core.http.HttpHeaders;
import com.aliyun.core.logging.ClientLogger;
import com.aliyun.core.utils.AttributeMap;
import darabonba.core.TeaConfiguration;
import darabonba.core.TeaPair;
import darabonba.core.TeaRequest;
import darabonba.core.client.ClientConfiguration;
import darabonba.core.client.ClientOption;
import darabonba.core.interceptor.InterceptorContext;
import darabonba.core.interceptor.RequestInterceptor;
import darabonba.core.utils.CommonUtil;

import java.util.Map;

public class V3ReqInterceptor implements RequestInterceptor {
    private final ClientLogger logger = new ClientLogger(V3ReqInterceptor.class);

    @Override
    public TeaRequest modifyRequest(InterceptorContext context, AttributeMap attributes) {
        logger.info("Request pre-process begin.");
        TeaRequest request = context.teaRequest();
        TeaConfiguration configuration = context.configuration();
        ClientConfiguration clientConfiguration = configuration.clientConfiguration();
        PopSigner signer = (PopSigner) clientConfiguration.option(ClientOption.SIGNER);
        if (signer.getSignerVersion() != SignatureVersion.V3) {
            return request;
        }

        Map<String, String> headers = CommonUtil.merge(String.class, CommonUtil.buildMap(
                new TeaPair("host", configuration.endpoint()),
                new TeaPair("accept", FormatType.JSON),
                new TeaPair("x-acs-version", request.version()),
                new TeaPair("x-acs-action", request.action()),
                new TeaPair("user-agent", clientConfiguration.option(ClientOption.USER_AGENT))
                ),
                request.headers().toMap()
        );

        request.setHeaders(new HttpHeaders(headers));
        return request;
    }
}

==> aliyun-gateway-pop-0.2.4-beta-sources.jar: com/aliyun/sdk/gateway/pop/interceptor/request/V3ReqInterceptor.java <==
package com.aliyun.sdk.gateway.pop.interceptor.request;

import com.aliyun.sdk.gateway.pop.auth.SignatureVersion;
import com.aliyun.sdk.gateway.pop.auth.signer.PopSigner;
import com.aliyun.core.http.FormatType;
import com.aliyun.core.http.HttpHeaders;
import com.aliyun.core.logging.ClientLogger;
import com.aliyun.core.utils.AttributeMap;
import darabonba.core.TeaConfiguration;
import darabonba.core.TeaPair;
import darabonba.core.TeaRequest;
import darabonba.core.client.ClientConfiguration;
import darabonba.core.client.ClientOption;
import darabonba.core.interceptor.InterceptorContext;
import darabonba.core.interceptor.RequestInterceptor;
import darabonba.core.utils.CommonUtil;

import java.util.Map;

public class V3ReqInterceptor implements RequestInterceptor {
    private final ClientLogger logger = new ClientLogger(V3ReqInterceptor.class);

    @Override
    public TeaRequest modifyRequest(InterceptorContext context, AttributeMap attributes) {
        logger.verbose("Request pre-process begin.");
        TeaRequest request = context.teaRequest();
        TeaConfiguration configuration = context.configuration();
        ClientConfiguration clientConfiguration = configuration.clientConfiguration();
        PopSigner signer = (PopSigner) clientConfiguration.option(ClientOption.SIGNER);
        if (signer.getSignerVersion() != SignatureVersion.V3) {
            return request;
        }

        Map<String, String> headers = CommonUtil.merge(String.class, CommonUtil.buildMap(
                new TeaPair("host", configuration.endpoint()),
                new TeaPair("accept", FormatType.JSON),
                new TeaPair("x-acs-version", request.version()),
                new TeaPair("x-acs-action", request.action()),
                new TeaPair("user-agent", clientConfiguration.option(ClientOption.USER_AGENT))
                ),
                request.headers().toMap()
        );

        request.setHeaders(new HttpHeaders(headers));
        return request;
    }
}
